==> mozc_1.4.1033.102.orig.tar.gz: mozc-1.4.1033.102/rewriter/calculator_rewriter.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_REWRITER_CALCULATOR_REWRITER_H_
#define MOZC_REWRITER_CALCULATOR_REWRITER_H_

#include <string>
#include "converter/segments.h"
#include "rewriter/rewriter_interface.h"

namespace mozc {

class CalculatorRewriterTest;
class ConversionRequest;
class Segments;

class CalculatorRewriter : public RewriterInterface {
 public:
  friend class CalculatorRewriterTest;

  CalculatorRewriter();
  virtual ~CalculatorRewriter();

  virtual bool Rewrite(Segments *segments) const;
  virtual bool RewriteForRequest(const ConversionRequest &request,
                                 Segments *segments) const;

 private:
  // Inserts a candidate with the string into the |segment|.
  // Position of insertion is indicated by |insert_pos|. It returns false if
  // insertion is failed.
  bool InsertCandidate(const string &value,
                       size_t insert_pos,
                       Segment *segment) const;
};

}  // namespace mozc

#endif  // MOZC_REWRITER_CALCULATOR_REWRITER_H_

==> mozc_1.5.1090.102.orig.tar.gz: mozc-1.5.1090.102/rewriter/calculator_rewriter.h <==
// Copyright 2010-2012, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef MOZC_REWRITER_CALCULATOR_REWRITER_H_
#define MOZC_REWRITER_CALCULATOR_REWRITER_H_

#include <string>
#include "converter/segments.h"
#include "rewriter/rewriter_interface.h"

namespace mozc {

class CalculatorRewriterTest;
class ConversionRequest;
class ConversionRequest;
class ConverterInterface;
class Segments;

class CalculatorRewriter : public RewriterInterface {
 public:
  friend class CalculatorRewriterTest;

  explicit CalculatorRewriter(const ConverterInterface *parent_converter);
  virtual ~CalculatorRewriter();

  virtual bool Rewrite(const ConversionRequest &request,
                       Segments *segments) const;

 private:
  // Inserts a candidate with the string into the |segment|.
  // Position of insertion is indicated by |insert_pos|. It returns false if
  // insertion is failed.
  bool InsertCandidate(const string &value,
                       size_t insert_pos,
                       Segment *segment) const;

  const ConverterInterface *parent_converter_;
};

}  // namespace mozc

#endif  // MOZC_REWRITER_CALCULATOR_REWRITER_H_
